@@ -655,8 +655,8 @@ class Simulation(http_client,metaclass=IterSimulation):
             toSet["ChokePumpFlowRateIn"] = self.setpoints.ChokePumpFlowRateIn
         if self.setpoints.DesiredROP is not None:
             toSet["DesiredROP"] = self.setpoints.DesiredROP
-        if self.setpoints.BOPChokeOpening is not None:
-            toSet["BopChokeOpening"] = self.setpoints.BOPChokeOpening
+        if self.setpoints.BopChokeOpening is not None:
+            toSet["BopChokeOpening"] = self.setpoints.BopChokeOpening
         if self.setpoints.MainPitActive is not None:
             toSet["MainPitActive"] = self.setpoints.MainPitActive
         if self.setpoints.MainPitReturn is not None:
